@@ -56,7 +56,7 @@ class RestrictedResource(models.Model):
 
     user = models.ForeignKey(User, null=True, blank=True)
     group = models.ForeignKey(Group, null=True, blank=True)
-    is_public = models.BooleanField()
+    is_public = models.BooleanField(default=False)
 
     objects = RestrictedResourceManager()
 
