@@ -54,9 +54,9 @@ class TestCaseWithInvariants(TestCaseWithScenarios):
         return self.scenarios
 
     def _dict_to_keys_and_values(self, d):
-        pairs = d.items()
-        keys = [first for (first, second) in pairs]
-        values = [second for (first, second) in pairs]
+        items = list(d.items())
+        keys = [first for (first, second) in items]
+        values = [second for (first, second) in items]
         return keys, values
 
     def _get_all_possible_scenarios(self, invariants):
@@ -75,7 +75,7 @@ class TestCaseWithInvariants(TestCaseWithScenarios):
                 k, v = self._dict_to_keys_and_values(value)
                 scenario_ids_list.append(k)
                 scenario_params_list.append(v)
-        for scenario_ids, scenario_params in itertools.izip(
+        for scenario_ids, scenario_params in zip(
             itertools.product(*scenario_ids_list),
                 itertools.product(*scenario_params_list)):
             parameters = dict(zip(invariant_keys, scenario_params))
@@ -90,10 +90,21 @@ class TestCaseWithInvariants(TestCaseWithScenarios):
     def setUp(self):
         super(TestCaseWithScenarios, self).setUp()
         # Evaluate lazy invariants now that `self' is around
-        for invariant in self._get_invariants().iterkeys():
+        for invariant in self._get_invariants().keys():
             value = getattr(self, invariant)
             if inspect.isfunction(value):
                 value = value(self)
+                # Some keys are lambda pointing to another key (which is
+                # sometime also a lambda). Depending on the order of the keys
+                # returned by .keys() the pointed value might still be a
+                # lambda.
+                # For instance with:
+                # invariants = {'owner': lambda self: ...,
+                #               'accessible_by_principal': lambda self: self.owner }
+                # when 'accessible_by_principal' is evaluated before 'owner',
+                # it should be evaluated twice.
+                if inspect.isfunction(value):
+                    value = value(self)
                 setattr(self, invariant, value)
 
 
@@ -120,7 +131,7 @@ class FixtureHelper(object):
         return value
 
     def getUniqueStringForField(self, model, field_name):
-        return self.getUniqueString(max_length=model._meta.get_field_by_name(field_name)[0].max_length)
+        return self.getUniqueString(max_length=model._meta.get_field(field_name).max_length)
 
     def getUniqueUser(self, is_active=True):
         user = User.objects.create(
