@@ -41,6 +41,9 @@ if hasattr(django, 'setup'):
 
 class ResourceCleanTests(FixtureHelper, TestCase):
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test_clean_raises_exception_when_owner_is_not_set(self):
         resource = RestrictedResource()
         self.assertRaises(ValidationError, resource.clean)
@@ -65,6 +68,9 @@ class ResourceCleanTests(FixtureHelper, TestCase):
 class ResourceOwnerTest(FixtureHelper, TestCase):
     """ Tests for the owner property """
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test_user_is_owner(self):
         user = self.getUniqueUser()
         resource = ExampleRestrictedResource(user=user)
@@ -103,6 +109,9 @@ class PrincipalTypeIsChecked(
         principal=[1, object(), {}, [], "string"],
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test_owner_assignment(self):
         resource = ExampleRestrictedResource()
         self.assertRaises(TypeError, setattr, resource, "owner", self.principal)
@@ -142,6 +151,9 @@ class OthersDoNotOwnResource(
         is_public=[True, False],
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test(self):
         resource = self.getUniqueResource(
             owner=self.owner, is_public=self.is_public)
@@ -163,6 +175,9 @@ class OwnerOwnsResource(
         is_public=[True, False],
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test(self):
         resource = self.getUniqueResource(
             owner=self.owner, is_public=self.is_public)
@@ -204,6 +219,9 @@ class ResourceManagerOwnerSetFindsNoMatchesForOthers(
         is_public=[True, False],
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test(self):
         manager = ExampleRestrictedResource.objects
         resource = self.getUniqueResource(
@@ -224,6 +242,9 @@ class ResourceManagerOwnerSetFindsMatchesForOwner(
         is_public=[True, False],
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test(self):
         for i in range(self.num_objects):
             self.getUniqueResource(
@@ -243,6 +264,9 @@ class ResourceManagerOwnerSetFindsMatchesForOwnerGroupMember(
         is_public=[True, False],
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test(self):
         group = self.getUniqueGroup()
         user = self.getUniqueUser()
@@ -277,6 +301,9 @@ class EveryoneHasPublicAccessToPublicResources(
         is_public=[True, False],
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def setUp(self):
         super(EveryoneHasPublicAccessToPublicResources, self).setUp()
         self.resource = self.getUniqueResource(
@@ -296,6 +323,9 @@ class NobodyButTheOwnerHasAccessToNonPublicUserResources(
         FixtureHelper, TestCaseWithInvariants):
     """ Tests for the get_access_type() method """
 
+    def __hash__(self):
+        return hash(repr(self))
+
     invariants = dict(
         accessing_principal=dict(
             nothing=None,
@@ -318,6 +348,9 @@ class OwnerHasPrivateAccessToNonPublicUserResources(
         FixtureHelper, TestCase):
     """ Tests for the get_access_type() method """
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test_owner(self):
         owner = self.getUniqueUser()
         resource = self.getUniqueResource(is_public=False, owner=owner)
@@ -329,6 +362,9 @@ class OwnerHasPrivateAccessToNonPublicUserResources(
 class GroupMembersGetSharedAccessToNonPublicGroupResources(
         FixtureHelper, TestCase):
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test_get_access_type_for_owning_group(self):
         owner = self.getUniqueGroup()
         resource = self.getUniqueResource(owner=owner, is_public=False)
@@ -363,6 +399,9 @@ class ResourceManagerAccessibleSetFindsOnlyPublicElementsForNonOwners(
         )
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test(self):
         manager = ExampleRestrictedResource.objects
         self.add_resources(["a", "b", "c"], owner=self.owner, is_public=True)
@@ -383,6 +422,9 @@ class ResourceManagerAccessibleByAnyoneSetFindsOnlyPublicElements(
         ),
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test(self):
         self.add_resources(["a", "b", "c"], owner=self.owner, is_public=True)
         self.add_resources(["x", "y", "z"], owner=self.owner, is_public=False)
@@ -403,6 +445,9 @@ class ResourceManagerAccessibleByPrincipalSetFindsAllOwnedlements(
         ),
     )
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def test(self):
         self.add_resources(["a", "b", "c"], owner=self.owner, is_public=True)
         self.add_resources(["x", "y", "z"], owner=self.owner, is_public=False)
@@ -416,6 +461,9 @@ class ResourceManagerAccessibleByPrincipalSetFindsAllOwnedlements(
 class ResourceManagerAccessibleSetTests(
         FixtureHelper, TestCase):
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def setUp(self):
         super(ResourceManagerAccessibleSetTests, self).setUp()
         self.user = self.getUniqueUser()
